@@ -1,4 +1,7 @@
 import requests
+import cloudscraper
+scraper = cloudscraper.create_scraper(
+    delay=10,   browser={'custom': 'ScraperBot/1.0', })
 
 
 class DRKApp:
@@ -51,6 +54,7 @@ class DRKApp:
             "vulnerabilities": "case/vulnerabilities/",
             "dropdowns": "case/dropdown/",
             "case_list": "case/all-case/",
+            "third-party": "case/third-party-case-details/",
         }
 
     def check_required_params(self):
@@ -105,7 +109,42 @@ class DRKApp:
             "origin": api_url
         }
 
-        response = requests.get(f"{api_url}{final_api}", headers=headers)
+        response = requests.get(
+            f"{api_url}{final_api}?api-key={self.token}", headers=headers)
+
+        if response.status_code == 200 or response.status_code == 201:
+            data = response.json()
+            return {"data": data, "status": response.status_code}
+        else:
+            raise Exception(
+                f"Failed to fetch data from API with status code {response.status_code} and message {response.text}")
+
+    def get_third_part_data(self, case_id=None):
+
+        api = self.api
+
+        """
+        Fetches data from the API based on the provided API type and source.
+        """
+        self.check_required_params()
+
+        if case_id is None:
+            raise ValueError("Case ID is required")
+
+        api_url = self.get_api_url()
+
+        final_api = self.all_api_list().get(api, None)
+
+        headers = {
+            "Authorization": f"Bearer {self.token}",
+            "Content-Type": "application/json",
+            "origin": api_url
+        }
+
+        response = requests.get(
+            f"{api_url}{final_api}{case_id}/?api-key={self.token}",
+            headers=headers
+        )
 
         if response.status_code == 200 or response.status_code == 201:
             data = response.json()
